# 安装方式
    pip uninstall astmain
    pip install   astmain


# 发布
    fit publish

# 依赖包
    pip install requests
    pip install pyppeteer
    pip install pyppeteer_stealth

    pip install arrow


    pip install nuitka
    pip install pytoml
    pip install flit











